@@ -24,6 +24,7 @@ import hildon
 import urllib2
 import urllib
 import httplib
+import socket
 import simplejson
 import bitly
 import accountData
@@ -101,8 +102,6 @@ class account():
         self.locationSetup=False
         self.dmnotify = pynotify.Notification("Witter","You have new DMs")
         self.dmnotify.add_action("clicked","Show DMs", self.dm_callback)
-        #TODO move this and check if the call can be put on background thread from main loop
-        #self.updateLocation()
         
     def updateLocation(self):    
         #start up location tracking
@@ -130,15 +129,18 @@ class account():
         self.control.start()
         
     def connect(self):
-        if self.accountdata.password:
-            print "Establishing api for " + self.accountdata.servicename + " using basic auth"
-            self.api = twitter.Api(username=self.accountdata.username, password=self.accountdata.password)
-            self.api.SetBaseUrl(self.accountdata.baseUrl)
-            self.api.SetBaseSearchUrl(self.accountdata.searchUrl)
+#        if self.accountdata.password:
+#            print "Establishing api for " + self.accountdata.servicename + " using basic auth"
+#            self.api = twitter.Api(username=self.accountdata.username, password=self.accountdata.password)
+#            self.api.SetBaseUrl(self.accountdata.baseUrl)
+#            self.api.SetBaseSearchUrl(self.accountdata.searchUrl)
             
         if (self.accountdata.access_token != None):
             print "Establishing api for " + self.accountdata.servicename + " using oauth"
-            self.api = oauthtwitter.OAuthApi(self.CONSUMER_KEY, self.CONSUMER_SECRET, self.accountdata.access_token)
+            self.api = twitter.Api(consumer_key=self.CONSUMER_KEY, 
+                                   consumer_secret=self.CONSUMER_SECRET, 
+                                   access_token_key=self.accountdata.access_token.key,
+                                   access_token_secret=self.accountdata.access_token.secret)
         if (self.api == None):
             print "Failed to establish api for " + self.accountdata.servicename
             return False
@@ -178,10 +180,9 @@ class account():
                     
                 avatar, loaded = self.retrieve_avatar(user.GetProfileImageUrl(), str(user.id)+".jpg")   
                 avatar = avatar.scale_simple(90, 90, gtk.gdk.INTERP_BILINEAR)
-                #self.controller.ui.profileImage.set_from_file("/home/user/.witterPics/" + self.accountdata.servicename + "/" + str(user.id)+".jpg")
                 self.controller.ui.profileImage.set_from_pixbuf(avatar)  
                 self.getSavedSearches()
-                self.getLists()
+                #self.getLists()
                 return
             except AttributeError, ae:
                 tryCount=tryCount+1
@@ -248,7 +249,10 @@ class account():
         if access_token:
             self.accountdata.access_token = access_token
             self.accountdata.accessType = "OAuth"
-            self.api = oauthtwitter.OAuthApi(self.CONSUMER_KEY, self.CONSUMER_SECRET, self.accountdata.access_token)
+            self.api = twitter.Api(consumer_key=self.CONSUMER_KEY, 
+                                   consumer_secret=self.CONSUMER_SECRET, 
+                                   access_token_key=self.accountdata.access_token.key,
+                                   access_token_secret=self.accountdata.access_token.secret)
             self.api.SetBaseUrl(self.accountdata.baseUrl)
 
     #accessor methods that return the entire list of data
@@ -278,8 +282,8 @@ class account():
                 return
             
         print "getting tweets with " + self.accountdata.username
-        print "base url = " + self.accountdata.baseUrl
-        print "base url of api object = " + self.api.GetBaseUrl()
+        #print "base url = " + self.accountdata.baseUrl
+        #print "base url of api object = " + self.api.GetBaseUrl()
         receive_count = 0
         tryCount=0
         while (tryCount <5):
@@ -287,69 +291,70 @@ class account():
                 #by default we get newer tweets
                 if (older == False):
                     if self.accountdata.last_id == None:
-                        data = self.api.GetFriendsTimeline()
-                        rtdata = self.api.GetRetweets_to_user()
+                        print "No last id"
+                        data = self.api.GetFriendsTimeline(retweets=True)
+                        #rtdata = self.api.GetRetweets_to_user()
                     else:
                         print "refreshing since" + str(self.accountdata.last_id)
-                        data = self.api.GetFriendsTimeline(since_id=self.accountdata.last_id, count=200)
-                        rtdata = self.api.GetRetweets_to_user(since_id=self.accountdata.last_id, count=200)
+                        data = self.api.GetFriendsTimeline(since_id=self.accountdata.last_id, count=100, retweets=True)
+                        #rtdata = self.api.GetRetweets_to_user(since_id=self.accountdata.last_id, count=100)
                 else:
                     if self.accountdata.oldest_id == None:
-                        data = self.api.GetFriendsTimeline(count=get_count)
+                        data = self.api.GetFriendsTimeline(count=get_count, retweets=True)
                         print "fetching retweets to user"
-                        rtdata = self.api.GetRetweets_to_user(count=get_count)
+                        #rtdata = self.api.GetRetweets_to_user(count=get_count)
                     else:
                         print "refreshing retweets prior to" + str(self.accountdata.oldest_id)
-                        data = self.api.GetFriendsTimeline(max_id=self.accountdata.oldest_id, count=get_count)
-                        rtdata = self.api.GetRetweets_to_user(max_id=self.accountdata.oldest_id, count=get_count)
-                data += rtdata
+                        data = self.api.GetFriendsTimeline(max_id=self.accountdata.oldest_id, count=get_count, retweets=True)
+                        #rtdata = self.api.GetRetweets_to_user(max_id=self.accountdata.oldest_id, count=get_count)
+                #data += rtdata
                 for x in data:
-                     if x != None:
-                         if (self.checkStoreForTweet(long(x.id),self.tweetstore)):
-                             print "Tweet already in store"
-                         else:
-                             if (self.accountdata.last_id != None):
+                    if x != None:
+                        if (self.checkStoreForTweet(long(x.id),self.tweetstore)):
+                            print "Tweet already in store"
+                        else:
+                            if (self.accountdata.last_id != None):
                                 if (x.id == self.accountdata.last_id):
                                     continue
-                             if (None != x.in_reply_to_status_id):
+                            if (None != x.in_reply_to_status_id):
                                 print "reply to " + x.in_reply_to_screen_name
                                 #we don't want anything showing up if there is no reply_to, so all teh formatting is held here including the newline
                                 reply_to = "In reply to: " + x.in_reply_to_screen_name + " - " + self.get_specific_tweet(x.in_reply_to_screen_name, x.in_reply_to_status_id)
-                             else:
+                            else:
                                 reply_to = ""
-        
-                             reply_to = reply_to.replace("&", "&amp;")
-                             #need to store id numbers for oldest/newest
-                             if self.accountdata.last_id == None:
+                               
+                            reply_to = reply_to.replace("&", "&amp;")
+                            #need to store id numbers for oldest/newest
+                            if self.accountdata.last_id == None:
                                 self.accountdata.last_id = x.id
-                             else:
+                            else:
                                 #if we have an id stored, check if this one is 'newer' if so then store it
-                                if long(self.accountdata.last_id) < long(x.id):
-                                    self.accountdata.last_id = x.id
-        
-                             #also want to track the oldest we get hold of
-                             if self.accountdata.oldest_id == None:
+                               if long(self.accountdata.last_id) < long(x.id):
+                                   self.accountdata.last_id = x.id
+                                   
+                            #also want to track the oldest we get hold of
+                            if self.accountdata.oldest_id == None:
                                 self.accountdata.oldest_id = x.id
-                             else:
+                            else:
                                 if long(self.accountdata.oldest_id) > long(x.id):
                                     self.accountdata.oldest_id = x.id
-                             #strip the source app name from the url
-                             source = self.getSourceAppname(x.source)
-                             text = self.escapeText(x.text)
-                             text = self.controller.expandBitlyUrls(text)
-                             if (x.GetPlace() !=None):
-                                 place = x.GetPlace().name
-                             else:
-                                 place=None
-                             
-                             pic = self.set_pic_for_id(str(x.user.GetId()), x.user.GetScreenName(), x.user.GetProfileImageUrl())
-                             created_at = self.parse_time(x.created_at)
-                             formatted_ts = self.format_timestamp(created_at)
-                             formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to, loc=place)
-                             longid= long(x.id)
-                             self.tweetstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", longid, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet, True])
-                             
-                             receive_count = receive_count + 1
+                            #strip the source app name from the url
+                            source = self.getSourceAppname(x.source)
+                            text = self.escapeText(x.text)
+                            text = self.controller.expandBitlyUrls(text)
+                            if (x.GetPlace() !=None):
+                                place = x.GetPlace().name
+                            else:
+                                place=None
+
+                            pic = self.set_pic_for_id(str(x.user.GetId()), x.user.GetScreenName(), x.user.GetProfileImageUrl())
+                            created_at = self.parse_time(x.created_at)
+                            formatted_ts = self.format_timestamp(created_at)
+                            formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to, loc=place)
+                            longid= long(x.id)
+                            self.tweetstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", longid, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet, True])
+                            
+                            receive_count = receive_count + 1
     
                 if (receive_count > 0):
                     note = osso.SystemNote(self.osso_c)
@@ -457,13 +462,11 @@ class account():
                         n = pynotify.Notification("Witter","You have "+str(receive_count)+" new mentions")
                         n.set_urgency(pynotify.URGENCY_CRITICAL)
                         icon= gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
-                        #n.add_action("clicked","Show DMs", self.dm_callback)
                         n.set_hint("dbus-callback-default", "uk.wouldd.witter /uk/wouldd/witter uk.wouldd.witter open_mentions")
                         n.set_icon_from_pixbuf(icon)
                         rpc = osso.Rpc(self.osso_c)
                         rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._ENABLE_LED,rpc_args=(self._LED_PATTERN,"",""),use_system_bus=True)
                         rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._VIBRATE,rpc_args=(self._VIBRATE_PATTERN,"",""),use_system_bus=True)
-                        #n.attach_to_widget(self.controller.ui.window)
                         n.show()
                 return
             except IOError, e:
@@ -563,9 +566,7 @@ class account():
                     rpc = osso.Rpc(self.osso_c)
                     rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._ENABLE_LED,rpc_args=(self._LED_PATTERN,"",""),use_system_bus=True)
                     rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._VIBRATE,rpc_args=(self._VIBRATE_PATTERN,"",""),use_system_bus=True)
-                    #dmnotify.add_action("clicked","Show DMs", self.dm_callback)
 
-                #n.attach_to_widget(self.controller.ui.window)
                 n.show()
         except IOError, e:
             print "error"
@@ -600,11 +601,11 @@ class account():
         self.friendsstore.clear()
         try:
             #by default we get newer tweets
-            page=0
+            page=-1
             followers = self.friendCount
             moreFriends=True
             while (moreFriends):
-                data = self.api.GetFriends(page=page)
+                data = self.api.GetFriends(cursor=page)
                 
                 if ((followers -100) > 0):
                     page=page+1
@@ -634,8 +635,9 @@ class account():
                         note = osso.SystemNote(self.osso_c)
                         result = note.system_note_infoprint(str(receive_count) + " Friends Received")
                     #update friend/follower counts etc
-
-                self.setProfileInfo()
+                
+                followers = followers - receive_count
+                
         except IOError, e:
             print "error"
             msg = 'Error retrieving friends '
@@ -659,6 +661,7 @@ class account():
             if (auto == 0):
                 note = osso.SystemNote(self.osso_c)
                 note.system_note_dialog("Network error occured. Please try again")
+        self.setProfileInfo()
                  
     def getPublic(self, auto=0, older=False, get_count=20, * args):
         if (self.api == None):
@@ -819,7 +822,6 @@ class account():
 
     def getSearch(self, searchTerms="", auto=0, older=False, get_count=20, * args):
         print "performing search"
-        #self.searchstore.clear()
         receive_count = 0
         #if we're not getting older tweets then pay attention to whether we want to clear search results
         if older==False:
@@ -944,7 +946,6 @@ class account():
         try:
             
             data = self.api.GetSavedSearches()
-
             
             print data
            
@@ -1057,8 +1058,6 @@ class account():
                         print "lat = %f, long = %f" % self.device.fix[4:6]
                         self.lat, self.long = self.device.fix[4:6]
             
-        #if (self.controller.location):
-        #    self.updateLocation()
         try:
 
             if (reply_to_name != None):
@@ -1228,7 +1227,7 @@ class account():
         #performs a 'newstyle' retweet for the specific tweet id
         print "retweeting "+str(id)
         try:
-            self.api.reTweet(long(id))
+            self.api.PostRetweet(long(id))
             note = osso.SystemNote(self.osso_c)
             result = note.system_note_infoprint("ReTweeted Successfully")
         
@@ -1255,7 +1254,7 @@ class account():
             if (auto == 0):
                 note = osso.SystemNote(self.osso_c)
                 note.system_note_dialog("Network error occured. Please try again")
-        except httplib.sslerror:
+        except socket.sslerror:
             print "Network error - SslError"
             if (auto == 0):
                 note = osso.SystemNote(self.osso_c)
@@ -1278,8 +1277,6 @@ class account():
         return self.set_pix(id + ".jpg", url, id, name)
 
     def set_pix(self, filename, url, id, name):
-        #print "looking for image /home/user/.witterPics/" + filename
-        #print "profile pic url " + url
         item = self.avatars.get_iter_first ()
         #first find out if we already loaded this avatar
         while (item != None):
@@ -1317,8 +1314,6 @@ class account():
         else:
             try:
                 pixbuf, success = self.retrieve_avatar(url, filename)
-                #urllib.urlretrieve(url, " / home / user / .witterPics / " + filename)
-                #print "profile pic retrieved"
                 if (success == True):
                     self.avatars.append([pixbuf, filename, 1, name])
                     self.update_all_avatars(id, pixbuf)
@@ -1450,7 +1445,6 @@ class account():
 
 
             msgDate = datetime.datetime.strptime(strippedDate, "%a %b %d %H:%M:%S +0000 %Y")
-            #msgDate = date.fromtimestamp(secsSinceEpoc)
         except ValueError:
             try:
                 print "trying timestamp format Mon, Jan 01 2010 00:00:00 +0000"
@@ -1467,8 +1461,6 @@ class account():
 
         timestamp = msgDate.time()
         print timestamp.tzinfo
-        #print datetime.datetime.tzname()
-        #msgDate = msgDate.astimezone(LocalTimezone())
         t = time.time()
 
         # we want something like '2007-10-18 14:00+0100'
@@ -1559,9 +1551,7 @@ class account():
             return
         if device.fix:
             if device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
-                #print "lat = %f, long = %f" % device.fix[4:6]
                 self.lat, self.long = device.fix[4:6]
-                #data.stop()
     
     def on_stop(self,control, data):
         print "quitting"
@@ -1572,4 +1562,4 @@ class account():
         return False
     
     
-        
\ No newline at end of file
+        
